<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>AppearancePage</name>
    <message>
        <location filename="../appearancepage.ui" line="20"/>
        <source>Style:</source>
        <translation>Styl:</translation>
    </message>
    <message>
        <location filename="../appearancepage.ui" line="59"/>
        <source>Preview</source>
        <translation>Náhled</translation>
    </message>
    <message>
        <location filename="../appearancepage.ui" line="69"/>
        <source>Active palette</source>
        <translation>Činná paleta</translation>
    </message>
    <message>
        <location filename="../appearancepage.ui" line="74"/>
        <source>Inactive palette</source>
        <translation>Nečinná paleta</translation>
    </message>
    <message>
        <location filename="../appearancepage.ui" line="79"/>
        <source>Disabled palette</source>
        <translation>Zakázaná paleta</translation>
    </message>
    <message>
        <location filename="../appearancepage.ui" line="113"/>
        <source>Palette</source>
        <translation>Paleta</translation>
    </message>
    <message>
        <location filename="../appearancepage.ui" line="124"/>
        <location filename="../appearancepage.cpp" line="88"/>
        <source>Default</source>
        <translation>Výchozí</translation>
    </message>
    <message>
        <location filename="../appearancepage.ui" line="134"/>
        <source>Custom</source>
        <translation>Vlastní</translation>
    </message>
    <message>
        <location filename="../appearancepage.ui" line="161"/>
        <source>Color scheme:</source>
        <translation>Barevné schéma:</translation>
    </message>
    <message>
        <location filename="../appearancepage.ui" line="187"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../appearancepage.ui" line="218"/>
        <source>Standard dialogs:</source>
        <translation>Běžné dialogy:</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="71"/>
        <source>Create</source>
        <translation>Vytvořit</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="72"/>
        <source>Edit</source>
        <translation>Upravit</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="73"/>
        <source>Create a Copy</source>
        <translation>Vytvořit kopii</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="74"/>
        <source>Rename</source>
        <translation>Přejmenovat</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="76"/>
        <source>Remove</source>
        <translation>Odstranit</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="143"/>
        <location filename="../appearancepage.cpp" line="217"/>
        <location filename="../appearancepage.cpp" line="256"/>
        <source>Enter Color Scheme Name</source>
        <translation>Zadejte název barevného schématu</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="143"/>
        <location filename="../appearancepage.cpp" line="217"/>
        <location filename="../appearancepage.cpp" line="256"/>
        <source>File name:</source>
        <translation>Název souboru:</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="152"/>
        <location filename="../appearancepage.cpp" line="228"/>
        <location filename="../appearancepage.cpp" line="236"/>
        <location filename="../appearancepage.cpp" line="266"/>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="152"/>
        <location filename="../appearancepage.cpp" line="228"/>
        <location filename="../appearancepage.cpp" line="266"/>
        <source>The color scheme &quot;%1&quot; already exists</source>
        <translation>Již je barevné schéma &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="170"/>
        <location filename="../appearancepage.cpp" line="193"/>
        <location filename="../appearancepage.cpp" line="251"/>
        <source>Warning</source>
        <translation>Varování</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="170"/>
        <location filename="../appearancepage.cpp" line="193"/>
        <location filename="../appearancepage.cpp" line="251"/>
        <source>The color scheme &quot;%1&quot; is read only</source>
        <translation>Barevné schéma &quot;%1&quot; je pouze pro čtení</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="198"/>
        <source>Confirm Remove</source>
        <translation>Potvrdit odstranění</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="199"/>
        <source>Are you sure you want to remove color scheme &quot;%1&quot;?</source>
        <translation>Jste si jistý, že chcete odstranit barevné schéma &quot;%1&quot;?</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="219"/>
        <source>%1 (copy)</source>
        <translation>%1 (kopie)</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="236"/>
        <source>Unable to copy file</source>
        <translation>Nelze zkopírovat soubor</translation>
    </message>
</context>
<context>
    <name>FontConfigDialog</name>
    <message>
        <location filename="../fontconfigdialog.ui" line="14"/>
        <location filename="../fontconfigdialog.cpp" line="73"/>
        <source>Font Configuration</source>
        <translation>Nastavení písma</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.ui" line="29"/>
        <source>Disable automatic hinting for bold fonts</source>
        <translation>Zakázat automatické podřezávání tučných písem</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.ui" line="36"/>
        <source>LCD filter:</source>
        <translation>Filtr LCD:</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.ui" line="43"/>
        <source>Automatic hinting</source>
        <translation>Automatické podřezávání</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.ui" line="50"/>
        <source>Hinting</source>
        <translation>Podřezávání</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.ui" line="67"/>
        <source>Font resolution:</source>
        <translation>Rozlišení písma:</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.ui" line="110"/>
        <source> dpi</source>
        <translation> DPI</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.ui" line="83"/>
        <source>Subpixel geometry:</source>
        <translation>Uspořádání subpixelů:</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.ui" line="90"/>
        <source>Antialiasing</source>
        <translation>Vyhlazování</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.ui" line="97"/>
        <source>Hinting style:</source>
        <translation>Styl podřezávání:</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.cpp" line="42"/>
        <location filename="../fontconfigdialog.cpp" line="47"/>
        <source>None</source>
        <translation>Žádný</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.cpp" line="43"/>
        <source>Slight</source>
        <translation>Menší</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.cpp" line="44"/>
        <source>Medium</source>
        <translation>Střední</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.cpp" line="45"/>
        <source>Full</source>
        <translation>Plné</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.cpp" line="74"/>
        <source>&lt;i&gt;%1&lt;/i&gt; already exists. Do you want to replace it?</source>
        <translation>&lt;i&gt;%1&lt;/i&gt; již existuje. Chcete jej nahradit?</translation>
    </message>
</context>
<context>
    <name>FontsPage</name>
    <message>
        <location filename="../fontspage.ui" line="47"/>
        <location filename="../fontspage.ui" line="67"/>
        <location filename="../fontspage.ui" line="86"/>
        <location filename="../fontspage.ui" line="93"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../fontspage.ui" line="60"/>
        <source>General:</source>
        <translation>Obecné:</translation>
    </message>
    <message>
        <location filename="../fontspage.ui" line="100"/>
        <source>Fixed width:</source>
        <translation>Pevná šířka:</translation>
    </message>
    <message>
        <location filename="../fontspage.ui" line="125"/>
        <source>Create  fonts.conf</source>
        <translation>Vytvořit fonts.conf</translation>
    </message>
    <message>
        <location filename="../fontspage.ui" line="132"/>
        <source>Remove fonts.conf</source>
        <translation>Odstranit fonts.conf</translation>
    </message>
    <message>
        <location filename="../fontspage.cpp" line="110"/>
        <source>Remove Font Configuration</source>
        <translation>Odstranit nastavení písma</translation>
    </message>
    <message>
        <location filename="../fontspage.cpp" line="111"/>
        <source>Are you sure you want to delete &lt;i&gt;%1&lt;/i&gt;?</source>
        <translation>Opravdu chcete smazat &lt;i&gt;%1&lt;/i&gt;?</translation>
    </message>
</context>
<context>
    <name>InterfacePage</name>
    <message>
        <location filename="../interfacepage.ui" line="35"/>
        <source>Double click interval:</source>
        <translation>Interval pro dvojité klepnutí:</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="42"/>
        <source>Cursor flash time:</source>
        <translation>Doba blikání ukazovátka:</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="49"/>
        <source>ComboBox effect:</source>
        <translation>Efekt rozbalovacího seznamu:</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="56"/>
        <source>ToolTip effect:</source>
        <translation>Efekt bublinové nápovědy:</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="63"/>
        <source>ToolBox effect:</source>
        <translation>Efekt nástrojové sady:</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="70"/>
        <location filename="../interfacepage.ui" line="80"/>
        <source> ms</source>
        <translation> ms</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="94"/>
        <location filename="../interfacepage.ui" line="111"/>
        <location filename="../interfacepage.ui" line="133"/>
        <location filename="../interfacepage.ui" line="157"/>
        <source>Disable</source>
        <translation>Zakázat</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="99"/>
        <location filename="../interfacepage.ui" line="116"/>
        <location filename="../interfacepage.ui" line="138"/>
        <location filename="../interfacepage.ui" line="162"/>
        <source>Animate</source>
        <translation>Animovat</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="121"/>
        <location filename="../interfacepage.ui" line="167"/>
        <source>Fade</source>
        <translation>Blednutí</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="146"/>
        <source>Menu effect:</source>
        <translation>Efekt nabídky:</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="175"/>
        <source>Enable gui effects</source>
        <translation>Povolit efekty rozhraní</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="182"/>
        <source>Dialog buttons layout:</source>
        <translation>Rozvržení tlačítek dialogu:</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="192"/>
        <source>Keyboard scheme:</source>
        <translation>Rozložení klávesnice:</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="202"/>
        <source>Menus have icons</source>
        <translation>Nabídky mají ikony</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="209"/>
        <source>Dialog buttons have icons</source>
        <translation>Dialogová tlačítka mají ikony</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="219"/>
        <source>Activate item on single-click</source>
        <translation>Zapnout položku jedním klepnutím</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="229"/>
        <source>Toolbar button style:</source>
        <translation>Styl tlačítka v nástrojovém pruhu:</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="239"/>
        <source>Mouse wheel scroll lines:</source>
        <translation>Kolečko myši posunuje řádky:</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="256"/>
        <source>Show shortcut underlines</source>
        <translation>Ukázat podtržení zkratek</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="266"/>
        <source>Show shortcuts in context menus</source>
        <translation>Ukázat zkratky v souvisejících nabídkách</translation>
    </message>
    <message>
        <location filename="../interfacepage.cpp" line="61"/>
        <source>Only display the icon</source>
        <translation>Zobrazit pouze ikonu</translation>
    </message>
    <message>
        <location filename="../interfacepage.cpp" line="62"/>
        <source>Only display the text</source>
        <translation>Zobrazit pouze text</translation>
    </message>
    <message>
        <location filename="../interfacepage.cpp" line="63"/>
        <source>The text appears beside the icon</source>
        <translation>Text se objeví vedle ikony</translation>
    </message>
    <message>
        <location filename="../interfacepage.cpp" line="64"/>
        <source>The text appears under the icon</source>
        <translation>Text se objeví pod ikonou</translation>
    </message>
    <message>
        <location filename="../interfacepage.cpp" line="65"/>
        <source>Follow the application style</source>
        <translation>Následovat styl programu</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>Qt5 Configuration Tool</source>
        <translation>Nástroj na nastavení Qt5</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="45"/>
        <source>The application is not configured correctly.</source>
        <translation>Program není nastaven správně.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="52"/>
        <source>Information</source>
        <translation>Informace</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="59"/>
        <source>Hide</source>
        <translation>Skrýt</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="50"/>
        <source>Appearance</source>
        <translation>Vzhled</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="51"/>
        <source>Fonts</source>
        <translation>Písma</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="52"/>
        <source>Icon Theme</source>
        <translation>Podoba ikon</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="53"/>
        <source>Interface</source>
        <translation>Rozhraní</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="55"/>
        <source>Style Sheets</source>
        <translation>Stylové listy</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="57"/>
        <source>Troubleshooting</source>
        <translation>Řešení potíží</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="64"/>
        <source>Version: %1</source>
        <translation>Verze: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="109"/>
        <source>Warning</source>
        <translation>Varování</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="118"/>
        <source>Please remove the &lt;b&gt;QT_STYLE_OVERRIDE&lt;/b&gt; environment variable (current value: &lt;b&gt;%1&lt;/b&gt;).</source>
        <translation>Odstraňte, prosím, proměnnou prostředí &lt;b&gt;QT_STYLE_OVERRIDE&lt;/b&gt; (nynější hodnota: &lt;b&gt;%1&lt;/b&gt;).</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="124"/>
        <source>The &lt;b&gt;QT_QPA_PLATFORMTHEME&lt;/b&gt; environment variable is not set (required value: &lt;b&gt;qt5ct&lt;/b&gt;).</source>
        <translation>Proměnná prostředí &lt;b&gt;QT_QPA_PLATFORMTHEME&lt;/b&gt; není nastavena správně (požadovaná hodnota: &lt;b&gt;qt5ct&lt;/b&gt;).</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="128"/>
        <source>The &lt;b&gt;QT_QPA_PLATFORMTHEME&lt;/b&gt; environment variable is not set correctly (current value: &lt;b&gt;%1&lt;/b&gt;, required value: &lt;b&gt;qt5ct&lt;/b&gt;).</source>
        <translation>Proměnná prostředí &lt;b&gt;QT_QPA_PLATFORMTHEME&lt;/b&gt; není nastavena správně (požadovaná hodnota: &lt;b&gt;%1&lt;/b&gt;, required value: &lt;b&gt;qt5ct&lt;/b&gt;).</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="135"/>
        <source>Unable to find &lt;b&gt;libqt5ct-style.so&lt;/b&gt;</source>
        <translation>Nelze najít &lt;b&gt;libqt5ct-style.so&lt;/b&gt;</translation>
    </message>
</context>
<context>
    <name>PaletteEditDialog</name>
    <message>
        <location filename="../paletteeditdialog.ui" line="14"/>
        <source>Palette Editor</source>
        <translation>Editor palety</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.ui" line="79"/>
        <source>Reset palette</source>
        <translation>Nastavit paletu znovu</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.ui" line="29"/>
        <source>Build inactive palette</source>
        <translation>Vytvořit nečinnou paletu</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.ui" line="36"/>
        <source>Build disabled palette</source>
        <translation>Vytvořit zakázanou paletu</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="49"/>
        <source>Active</source>
        <translation>Činná</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="49"/>
        <source>Inactive</source>
        <translation>Nečinná</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="49"/>
        <source>Disabled</source>
        <translation>Zakázaná</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="91"/>
        <source>Dark</source>
        <translation>Tmavé</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="91"/>
        <source>Window text</source>
        <translation>Text okna</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="91"/>
        <source>Button background</source>
        <translation>Pozadí tlačítka</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="91"/>
        <source>Bright</source>
        <translation>Světlé</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="91"/>
        <source>Less bright</source>
        <translation>Méně světlé</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="91"/>
        <source>Less dark</source>
        <translation>Tmavé</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="92"/>
        <source>Window</source>
        <translation>Okno</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="92"/>
        <source>Shadow</source>
        <translation>Stín</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="92"/>
        <source>Bright text</source>
        <translation>Světlý text</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="92"/>
        <source>Button text</source>
        <translation>Text tlačítka</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="92"/>
        <source>Normal text</source>
        <translation>Běžný text</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="92"/>
        <source>Normal background</source>
        <translation>Běžné pozadí</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="93"/>
        <source>Highlight</source>
        <translation>Zvýrazněná oblast</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="93"/>
        <source>Highlighted text</source>
        <translation>Zvýrazněný text</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="93"/>
        <source>Visited link</source>
        <translation>Navštívený odkaz</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="94"/>
        <source>Default</source>
        <translation>Výchozí</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="94"/>
        <source>Tooltip background</source>
        <translation>Pozadí bublinové nápovědy</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="94"/>
        <source>Tooltip text</source>
        <translation>Text bublinové nápovědy</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="93"/>
        <source>Link</source>
        <translation>Odkaz</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="94"/>
        <source>Alternate background</source>
        <translation>Náhradní pozadí</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="96"/>
        <source>Placeholder text</source>
        <translation>Text zástupného znaku</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="109"/>
        <source>Select Color</source>
        <translation>Vybrat barvu</translation>
    </message>
</context>
<context>
    <name>PreviewForm</name>
    <message>
        <location filename="../previewform.ui" line="14"/>
        <source>Preview Window</source>
        <translation>Náhledové okno</translation>
    </message>
    <message>
        <location filename="../previewform.ui" line="27"/>
        <source>Tab 1</source>
        <translation>Karta 1</translation>
    </message>
    <message>
        <location filename="../previewform.ui" line="36"/>
        <source>PushButton</source>
        <translation>Tlačítko</translation>
    </message>
    <message>
        <location filename="../previewform.ui" line="65"/>
        <source>Tab 2</source>
        <translation>Karta 2</translation>
    </message>
    <message>
        <location filename="../previewform.ui" line="74"/>
        <source>RadioButton</source>
        <translation>Přepínač</translation>
    </message>
    <message>
        <location filename="../previewform.ui" line="84"/>
        <source>CheckBox</source>
        <translation>Zaškrtávací okénko</translation>
    </message>
</context>
<context>
    <name>QSSEditorDialog</name>
    <message>
        <location filename="../qsseditordialog.cpp" line="46"/>
        <source>%1 - Style Sheet Editor</source>
        <translation>%1 - Editor stylových listů</translation>
    </message>
    <message>
        <location filename="../qsseditordialog.ui" line="14"/>
        <source>Style Sheet Editor</source>
        <translation>Editor stylového listu</translation>
    </message>
</context>
<context>
    <name>QSSPage</name>
    <message>
        <location filename="../qsspage.ui" line="23"/>
        <source>Create</source>
        <translation>Vytvořit</translation>
    </message>
    <message>
        <location filename="../qsspage.ui" line="66"/>
        <location filename="../qsspage.cpp" line="51"/>
        <location filename="../qsspage.cpp" line="87"/>
        <source>Edit</source>
        <translation>Upravit</translation>
    </message>
    <message>
        <location filename="../qsspage.ui" line="76"/>
        <location filename="../qsspage.cpp" line="53"/>
        <source>Rename</source>
        <translation>Přejmenovat</translation>
    </message>
    <message>
        <location filename="../qsspage.ui" line="33"/>
        <location filename="../qsspage.cpp" line="55"/>
        <source>Remove</source>
        <translation>Odstranit</translation>
    </message>
    <message>
        <location filename="../qsspage.cpp" line="52"/>
        <source>Create a Copy</source>
        <translation>Vytvořit kopii</translation>
    </message>
    <message>
        <location filename="../qsspage.cpp" line="92"/>
        <source>View</source>
        <translation>Pohled</translation>
    </message>
    <message>
        <location filename="../qsspage.cpp" line="106"/>
        <location filename="../qsspage.cpp" line="251"/>
        <source>File name:</source>
        <translation>Název souboru:</translation>
    </message>
    <message>
        <location filename="../qsspage.cpp" line="106"/>
        <location filename="../qsspage.cpp" line="251"/>
        <source>Enter Style Sheet Name</source>
        <translation>Zadejte název stylového listu</translation>
    </message>
    <message>
        <location filename="../qsspage.cpp" line="117"/>
        <location filename="../qsspage.cpp" line="218"/>
        <location filename="../qsspage.cpp" line="226"/>
        <location filename="../qsspage.cpp" line="263"/>
        <location filename="../qsspage.cpp" line="271"/>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <location filename="../qsspage.cpp" line="117"/>
        <source>The file &quot;%1&quot; already exists</source>
        <translation>Již je soubor &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../qsspage.cpp" line="151"/>
        <source>Confirm Remove</source>
        <translation>Potvrdit odstranění</translation>
    </message>
    <message>
        <location filename="../qsspage.cpp" line="152"/>
        <source>Are you sure you want to remove style sheet &quot;%1&quot;?</source>
        <translation>Jste si jistý, že chcete odstranit stylový list &quot;%1&quot;?</translation>
    </message>
    <message>
        <location filename="../qsspage.cpp" line="208"/>
        <source>Rename Style Sheet</source>
        <translation>Přejmenovat stylový list</translation>
    </message>
    <message>
        <location filename="../qsspage.cpp" line="208"/>
        <source>Style sheet name:</source>
        <translation>Název stylového listu:</translation>
    </message>
    <message>
        <location filename="../qsspage.cpp" line="218"/>
        <location filename="../qsspage.cpp" line="263"/>
        <source>The style sheet &quot;%1&quot; already exists</source>
        <translation>Již je stylový list &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../qsspage.cpp" line="226"/>
        <source>Unable to rename file</source>
        <translation>Nelze přejmenovat soubor</translation>
    </message>
    <message>
        <location filename="../qsspage.cpp" line="253"/>
        <source>%1 (copy).qss</source>
        <translation>%1 (kopie).qss</translation>
    </message>
    <message>
        <location filename="../qsspage.cpp" line="271"/>
        <source>Unable to copy file</source>
        <translation>Nelze zkopírovat soubor</translation>
    </message>
</context>
<context>
    <name>TroubleshootingPage</name>
    <message>
        <location filename="../troubleshootingpage.ui" line="20"/>
        <source>Ignored applications:</source>
        <translation>Přehlížené programy:</translation>
    </message>
    <message>
        <location filename="../troubleshootingpage.ui" line="29"/>
        <source>Add...</source>
        <translation>Přidat...</translation>
    </message>
    <message>
        <location filename="../troubleshootingpage.ui" line="40"/>
        <source>Remove</source>
        <translation>Odstranit</translation>
    </message>
    <message>
        <location filename="../troubleshootingpage.ui" line="73"/>
        <source>Do not apply any styles and color schemes for the listed applications.</source>
        <translation>Na v seznamu uvedené aplikace nepoužívat žádné styly a barevná schémata.</translation>
    </message>
    <message>
        <location filename="../troubleshootingpage.ui" line="82"/>
        <source>Make top-level widgets use pure raster surfaces, and do not support non-native GL-based child widgets.</source>
        <translation>Nechat grafické prvky nejvyšší úrovně používat čistě rastrové povrchy a nepodporovat nenativní podřízené prvky založené na GL.</translation>
    </message>
    <message>
        <location filename="../troubleshootingpage.ui" line="85"/>
        <source>Force raster surface</source>
        <translation>Vynutit rastrový povrch</translation>
    </message>
    <message>
        <location filename="../troubleshootingpage.cpp" line="64"/>
        <source>Select Application</source>
        <translation>Vybrat program</translation>
    </message>
    <message>
        <location filename="../troubleshootingpage.cpp" line="64"/>
        <source>Executable files (*)</source>
        <translation>Spustitelné soubory (*)</translation>
    </message>
</context>
</TS>
